from django.db import models
from django.contrib.auth.models import User
from django.core.validators import RegexValidator, MinLengthValidator, URLValidator
import uuid
import datetime

from django.forms import ValidationError

def validate_age(date_input):
    date_today = datetime.date.today()
    age = date_today.year - date_input.year - ((date_today.month, date_today.day) < (date_input.month, date_input.day))

    if age < 12:
        raise ValidationError('Usia minimal harus 12 tahun.')
    

class CustomUser(models.Model):
    user = models.OneToOneField(User, on_delete=models.CASCADE)
    role = models.CharField(max_length=20, default='normal')
    nama = models.CharField(
        max_length=255,
        validators = [
            RegexValidator(
                regex=r'^[a-zA-Z0-9._\-]{1,255}$',
                message = "Hanya terdiri dari huruf, angka, \'.\', \'_\', \'-\'"
            )
        ]
    )


    password = models.CharField(
        max_length=255,
        validators = [
            RegexValidator(
                regex= r'^[a-zA-Z0-9!@#$%^&*()_+{}\[\]:"|<>,.?/~`-]{8,255}$',
                message = "Panjang minimal 8 karakter dan hanya bisa terdiri dari huruf, angka, dan karakter spesial, tanpa spasi"
            ),
        ]
    )
    

    tanggal_lahir = models.DateField(
        error_messages = {
            'invalid': "Format: YYYY-MM-DD"
        },
        validators=[
            validate_age
        ]
    )


    nomor_hp = models.CharField(
        max_length=15,
        validators = [
            RegexValidator(
                regex=r'^\d{8,15}$',
                message = "Format: Kode negara-nomor telepon (tanpa spasi). Contoh: 62123456789"
            )
        ]
    )

    email = models.CharField(
        max_length=255,
        validators = [
            RegexValidator(
                regex=r'^[a-z0-9._+-]+@gmail\.com$',
                message= "Format: example@gmail.com"
            )
        ]
    )

    url_blog = models.CharField(
        max_length=255,
        validators = [
            URLValidator(
                message = "Masukkan format URL yang sesuai. Contoh: https://example.com"
            )
        ]
    )

    deskripsi = models.TextField(
        max_length=1000,
        validators = [
            MinLengthValidator(5)
        ]
    )
    
    no_polis_asuransi = models.CharField(
        max_length = 10,
        validators = [
            RegexValidator(
                regex=r'^\d{5,10}$',
                message= "Enter 5-10 digits"
            ),
        ]
    )

    kode_faskes_primer = models.CharField(
        max_length=8,
        validators = [
            RegexValidator(
                regex = r'^F\-[a-zA-Z0-9]{6}$',
                message = "Format: F-XXXXXX, X: Alphanumeric"
            ),
        ]
    )




