from django.http import HttpResponse
from django.shortcuts import get_object_or_404, render, redirect
from main.forms import CustomUserForm
from main.models import CustomUser
from django.contrib.auth.models import User
from django.contrib.auth.forms import UserCreationForm
from django.contrib import messages
from django.contrib.auth.forms import AuthenticationForm
from django.contrib.auth import login, logout

def show_main(request):
    user_id = request.session.get('user_id')
    if user_id:
        user = get_object_or_404(User, id=user_id)
        custom_user = get_object_or_404(CustomUser, user=user)
        context = {'custom_user': custom_user}
   
        return render(request, "main.html", context)


    

def show_home(request):
    user_active_id = request.session.get('user_active_id')
    user = User.objects.get(id=user_active_id)
    custom_user = CustomUser.objects.get(user=user)
    
    context = {'user': custom_user, 'is_staff': user.is_staff}
    return render(request, "home.html", context)
    

def login_user(request):
    if request.method == 'POST':
        form = AuthenticationForm(data=request.POST)

        if form.is_valid():
            user = form.get_user()
            login(request, user)
            
            
            request.session['user_active_id'] = user.id

            return redirect("main:show_home")
        
        
        else:
            messages.error(request, "Invalid username or password. Please try again.")

    else:
        form = AuthenticationForm(request)

    context = {'form': form}
    return render(request, 'login.html', context)


def logout_user(request):
    logout(request) 
    return redirect('main:login')






def create_admin_user(request):
    if request.method == "POST":
        form = CustomUserForm(request.POST)

        if form.is_valid():
            custom_user = form.save(commit=False)
            

            user = User.objects.create_user(
                username=form.cleaned_data['nama'],
                email=form.cleaned_data['email'],
                password=form.cleaned_data['password'],
                is_staff=True,
                is_superuser=True
            )


            custom_user.user = user
            custom_user.role = "admin"
            custom_user.save()

            request.session['user_id'] = user.id
            

            
            return redirect('main:show_main')
    else:
        form = CustomUserForm()


    return render(request, "create_user.html", {'form': form, 'judul': 'Create Admin'})


def create_normal_user(request):
    if request.method == "POST":
        form = CustomUserForm(request.POST)

        if form.is_valid():
            custom_user = form.save(commit=False)
            

            user = User.objects.create_user(
                username=form.cleaned_data['nama'],
                email=form.cleaned_data['email'],
                password=form.cleaned_data['password']
            )


            custom_user.user = user
            custom_user.role = "normal"
            custom_user.save()


            request.session['user_id'] = user.id
            

            
            return redirect('main:show_main')
    else:
        form = CustomUserForm()


    return render(request, "create_user.html", {'form': form, 'judul': 'Create Normal User'})